@@ -79,9 +79,7 @@ def _print_version(ctx: click.Context, _, value: str):
 
 
 def _instantiate_project(
-    requirements: str,
-    requirements_locked: Optional[str] = None,
-    runtime_environment: RuntimeEnvironment = None,
+    requirements: str, requirements_locked: Optional[str] = None, runtime_environment: RuntimeEnvironment = None,
 ):
     """Create Project instance based on arguments passed to CLI."""
     try:
@@ -100,11 +98,7 @@ def _instantiate_project(
             requirements_locked = requirements_locked.replace("\\n", "\n")
 
     pipfile = Pipfile.from_string(requirements)
-    pipfile_lock = (
-        PipfileLock.from_string(requirements_locked, pipfile)
-        if requirements_locked
-        else None
-    )
+    pipfile_lock = PipfileLock.from_string(requirements_locked, pipfile) if requirements_locked else None
     project = Project(
         pipfile=pipfile,
         pipfile_lock=pipfile_lock,
@@ -114,9 +108,7 @@ def _instantiate_project(
     return project
 
 
-def _get_adviser_predictor(
-    predictor: str, recommendation_type: RecommendationType
-) -> type:
+def _get_adviser_predictor(predictor: str, recommendation_type: RecommendationType) -> type:
     """Get adviser predictor based on command line option."""
     if predictor != "AUTO":
         return getattr(predictors, predictor)
@@ -126,20 +118,31 @@ def _get_adviser_predictor(
     elif (
         recommendation_type == RecommendationType.STABLE
         or recommendation_type == RecommendationType.TESTING
+        or recommendation_type == RecommendationType.PERFORMANCE
+        or recommendation_type == RecommendationType.SECURITY
     ):
         return predictors.MCTS
 
     raise ValueError(f"Unknown recommendation type: {recommendation_type!r}")
 
 
+def _get_dependency_monkey_predictor(predictor: str, decision_type: DecisionType) -> type:
+    """Get dependency monkey predictor based on command line option."""
+    if predictor != "AUTO":
+        return getattr(predictors, predictor)
+
+    if decision_type == DecisionType.RANDOM:
+        return predictors.RandomWalk
+    elif decision_type == DecisionType.ALL:
+        return predictors.ApproximatingLatest
+
+    raise ValueError(f"Unknown decision type: {decision_type!r}")
+
+
 @click.group()
 @click.pass_context
 @click.option(
-    "-v",
-    "--verbose",
-    is_flag=True,
-    envvar="THOTH_ADVISER_DEBUG",
-    help="Be verbose about what's going on.",
+    "-v", "--verbose", is_flag=True, envvar="THOTH_ADVISER_DEBUG", help="Be verbose about what's going on.",
 )
 @click.option(
     "--version",
@@ -231,8 +234,7 @@ def provenance(
         project = _instantiate_project(requirements, requirements_locked)
         result["parameters"]["project"] = project.to_dict()
         report = project.check_provenance(
-            whitelisted_sources=whitelisted_sources,
-            digests_fetcher=GraphDigestsFetcher(),
+            whitelisted_sources=whitelisted_sources, digests_fetcher=GraphDigestsFetcher(),
         )
     except (AdviserException, UnsupportedConfiguration) as exc:
         if isinstance(exc, InternalError):
@@ -242,9 +244,7 @@ def provenance(
         _LOGGER.exception("Error during checking provenance: %s", str(exc))
         result["error"] = True
         result["error_msg"] = str(exc)
-        result["report"] = [
-            {"type": "ERROR", "justification": f"{str(exc)} ({type(exc).__name__})"}
-        ]
+        result["report"] = [{"type": "ERROR", "justification": f"{str(exc)} ({type(exc).__name__})"}]
     else:
         result["error"] = False
         result["error_msg"] = None
@@ -342,9 +342,7 @@ def provenance(
     type=str,
     help="Runtime environment specification (file or directly JSON) to describe target environment.",
 )
-@click.option(
-    "--plot", envvar="THOTH_ADVISER_PLOT", type=str, help="Plot history of predictor."
-)
+@click.option("--plot", envvar="THOTH_ADVISER_PLOT", type=str, help="Plot history of predictor.")
 @click.option(
     "--beam-width",
     "-b",
@@ -382,8 +380,8 @@ def provenance(
     default=True,
     show_default=True,
     help="Turn off or on user stack scoring - the lock file supplied, if any, will be used "
-         "as a base for relative stack quality comparision. Adviser will score the supplied "
-         "lock file and will try to find a better stack.",
+    "as a base for relative stack quality comparision. Adviser will score the supplied "
+    "lock file and will try to find a better stack.",
 )
 @click.option(
     "--dev/--no-dev",
@@ -423,7 +421,7 @@ def advise(
         if os.path.isfile(library_usage):
             try:
                 library_usage = json.loads(Path(library_usage).read_text())
-            except Exception as exc:
+            except Exception:
                 _LOGGER.error("Failed to load library usage file %r", library_usage)
                 raise
         else:
@@ -432,9 +430,7 @@ def advise(
     runtime_environment = RuntimeEnvironment.load(runtime_environment)
     recommendation_type = RecommendationType.by_name(recommendation_type)
     requirements_format = PythonRecommendationOutput.by_name(requirements_format)
-    project = _instantiate_project(
-        requirements, requirements_locked, runtime_environment
-    )
+    project = _instantiate_project(requirements, requirements_locked, runtime_environment)
     pipeline_config = None if pipeline is None else PipelineBuilder.load(pipeline)
 
     parameters["project"] = project.to_dict()
@@ -445,9 +441,7 @@ def advise(
     # Use current time to make sure we have possibly reproducible runs - the seed is reported.
     seed = seed if seed is not None else int(time.time())
     _LOGGER.info(
-        "Starting resolver using %r predictor with random seed set to %r",
-        predictor_class.__name__,
-        seed,
+        "Starting resolver using %r predictor with random seed set to %r", predictor_class.__name__, seed,
     )
     random.seed(seed)
 
@@ -579,9 +573,7 @@ def advise(
     type=str,
     help="Runtime environment specification (file or directly JSON) to describe target environment.",
 )
-@click.option(
-    "--plot", envvar="THOTH_ADVISER_PLOT", type=str, help="Plot predictor history."
-)
+@click.option("--plot", envvar="THOTH_ADVISER_PLOT", type=str, help="Plot predictor history.")
 @click.option(
     "--beam-width",
     "-b",
@@ -601,8 +593,8 @@ def advise(
 @click.option(
     "--predictor",
     envvar="THOTH_ADVISER_PREDICTOR",
-    default="RandomWalk",
-    type=click.Choice(predictors.__all__),
+    default="AUTO",
+    type=click.Choice(predictors.__all__ + ["AUTO"]),
     help="Predictor to be used with the resolver.",
 )
 @click.option(
@@ -651,17 +643,16 @@ def dependency_monkey(
         if os.path.isfile(library_usage):
             try:
                 library_usage = json.loads(Path(library_usage).read_text())
-            except Exception as exc:
+            except Exception:
                 _LOGGER.error("Failed to load library usage file %r", library_usage)
                 raise
         else:
             library_usage = json.loads(library_usage)
 
     runtime_environment = RuntimeEnvironment.load(runtime_environment)
+    decision_type = DecisionType.by_name(decision_type)
     requirements_format = PythonRecommendationOutput.by_name(requirements_format)
-    project = _instantiate_project(
-        requirements, runtime_environment=runtime_environment
-    )
+    project = _instantiate_project(requirements, runtime_environment=runtime_environment)
     pipeline_config = None if pipeline is None else PipelineBuilder.load(pipeline)
 
     parameters["project"] = project.to_dict()
@@ -670,15 +661,14 @@ def dependency_monkey(
 
     # Use current time to make sure we have possibly reproducible runs - the seed is reported.
     seed = seed if seed is not None else int(time.time())
+    predictor_class = _get_dependency_monkey_predictor(predictor, decision_type)
     _LOGGER.info(
-        "Starting resolver using predictor %r with random seed set to %r",
-        predictor,
-        seed,
+        "Starting resolver using predictor %r with random seed set to %r", predictor_class.__name__, seed,
     )
     random.seed(seed)
 
     resolver = Resolver.get_dependency_monkey_instance(
-        predictor=getattr(predictors, predictor)(keep_history=plot is not None),
+        predictor=predictor_class(keep_history=plot is not None),
         project=project,
         library_usage=library_usage,
         count=count,
